"""
config
===============================================================================
"""
from __future__ import annotations
from typing import TYPE_CHECKING

import wx.stc as stc
from wbBase.control.textEditControl import PyTextEditConfig
from wbBase.dialog.preferences import PreferencesPageBase

if TYPE_CHECKING:
    from .control import NameSpace

name = "Namespace"

class NameSpaceConfig(PyTextEditConfig):
    def __init__(self, parent):
        super().__init__(parent)
        self.ShowLineNumbers = False
        self.WrapMode = stc.STC_WRAP_WORD

    def appendProperties(self, page):
        """
        Append properties to PreferencesPage
        """
        self.registerPropertyEditors(page)
        self.appendProperties_main(page)
        self.appendProperties_caret(page)
        self.appendProperties_selection(page)
        # self.appendProperties_indentation(page)
        # self.appendProperties_line_ending(page)
        self.appendProperties_line_warp(page)
        # self.appendProperties_line_numbers(page)
        # self.appendProperties_code_folding(page)
        self.appendProperties_syntax_colour(page)


class NameSpacePreferences(PreferencesPageBase):
    """
    Additional page for the preferences dialog of the
    Workbench application.
    """
    def __init__(self, parent):
        PreferencesPageBase.__init__(self, parent)
        self.settings = NameSpaceConfig(self)
        self.settings.appendProperties(self)

        self.name = name

    def applyValues(self):
        """
        Apply configuration to the namespace panel.
        """
        win:NameSpace = self.app.TopWindow.panelManager.getWindowByCaption(self.name)
        if win:
            self.settings.getPropertyValues(self)
            tree = win.tree
            tree.SetBackgroundColour(self.settings.backgroundColour.ChangeLightness(130))
            tree.SetForegroundColour(self.settings.foregroundColour)
            self.settings.apply(win.text)

    def saveValues(self):
        self.applyValues()
        self.settings.save()



"""
control
===============================================================================
"""
from __future__ import annotations

from typing import TYPE_CHECKING

import wx
from wx import aui
from wbBase.control import PanelMixin
from wbBase.control.filling import Filling

from .config import NameSpaceConfig, name

if TYPE_CHECKING:
    pass


class NameSpace(Filling, PanelMixin):
    def __init__(
        self,
        parent: wx.Window,
        id: int = wx.ID_ANY,
        pos: wx.Point = wx.DefaultPosition,
        size: wx.Size = wx.DefaultSize,
        style: int = wx.SP_LIVE_UPDATE
        | wx.SP_NOBORDER
        | wx.SP_NO_XP_THEME
        | wx.NO_BORDER,
    ):
        super().__init__(
            parent,
            id,
            pos,
            size,
            style,
            name="NameSpace",
            rootObject=None,
            rootLabel="NameSpace",
            rootIsNamespace=True,
            static=False,
        )
        self.settings = NameSpaceConfig(self)
        self.settings.load()
        tree = self.tree
        tree.SetBackgroundColour(self.settings.backgroundColour.ChangeLightness(130))
        tree.SetForegroundColour(self.settings.foregroundColour)
        self.settings.apply(self.text)

nameSpaceInfo = aui.AuiPaneInfo()
nameSpaceInfo.Name(name)
nameSpaceInfo.Caption(name)
nameSpaceInfo.MaximizeButton(True)
nameSpaceInfo.MinimizeButton(True)
nameSpaceInfo.CloseButton(False)
nameSpaceInfo.Right()
nameSpaceInfo.Dock()
nameSpaceInfo.Hide()
nameSpaceInfo.Resizable()
nameSpaceInfo.MinSize(150, 100)
nameSpaceInfo.BestSize(250, 200)
nameSpaceInfo.Icon(wx.ArtProvider.GetBitmap("NAMESPACE", wx.ART_FRAME_ICON))

nameSpacePanel = (NameSpace, nameSpaceInfo)


"""
wbpNamespace
===============================================================================

Tree view to inspect the namespace of the application
"""

from .config import NameSpacePreferences
from .control import nameSpacePanel

__version__ = "0.1.8"


panels = [nameSpacePanel]
preferencepages = [NameSpacePreferences]
